@@ -1,2 +1,2 @@
-from .other import middle,change
+from .other import middle,change,find_path
 from .percent import per_of,per_is,per_from
\ No newline at end of file
